@@ -1,5 +1,5 @@
 package Class::Closure;
-$Class::Closure::VERSION = '0.301';
+$Class::Closure::VERSION = '0.302';
 # ABSTRACT: Encapsulated, declarative class style
 
 use 5.006;
@@ -178,7 +178,7 @@ sub extends($) { &$EXTENDS }
 sub destroy(&) { _install DESTROY => \Class::Closure::DestroyDelegate->new( $_[0] ) }
 
 package Class::Closure::DestroyDelegate;
-$Class::Closure::DestroyDelegate::VERSION = '0.301';
+$Class::Closure::DestroyDelegate::VERSION = '0.302';
 sub new { bless $_[1] }
 sub DESTROY { goto &{$_[0]} }
 
@@ -188,13 +188,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Class::Closure - Encapsulated, declarative class style
 
 =head1 VERSION
 
-version 0.301
+version 0.302
 
 =head1 SYNOPSIS
 
@@ -430,19 +432,11 @@ code. Bug reports/patches welcome.
 
 L<Class::Struct>, L<Class::Classless>
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Aristotle Pagaltzis <pagaltzis@gmx.de>
 
-=item *
-
-Luke Palmer
-
-=back
+Documentation by Luke Palmer.
 
 =head1 COPYRIGHT AND LICENSE
 
